@@ -4,5 +4,7 @@ one <- subset(neuroblastoma$profiles,profile.id==clin.id)
 these.labels <- subset(neuroblastoma$annotations,profile.id==clin.id)
 print(these.labels)
 library(bams)
-run.smoothers(one,these.labels,article.smoothers)
+update.names <- c("gada",grep("cghseg",names(smoothers),value=TRUE))
+update.smoothers <- smoothers[update.names]
+run.smoothers(one, these.labels, update.smoothers)
 
